@@ -107,25 +107,18 @@ void Doctor::start(QCommandLineParser *parser)
         const QString dpmsArg = m_parser->value(QStringLiteral("dpms"));
         if (dpmsArg == QLatin1String("show")) {
         } else {
-            auto performSwitch = [this, dpmsArg, screens](bool supported) {
-                if (!supported) {
-                    cerr << "DPMS not supported in this system";
-                    qGuiApp->quit();
-                    return;
-                }
+            if (!m_dpmsClient->isSupported()) {
+                cerr << "DPMS not supported in this system";
+                qGuiApp->quit();
+                return;
+            }
 
-                if (dpmsArg == QLatin1String("off")) {
-                    m_dpmsClient->switchMode(KScreen::Dpms::Off, screens);
-                } else if (dpmsArg == QLatin1String("on")) {
-                    m_dpmsClient->switchMode(KScreen::Dpms::On, screens);
-                } else {
-                    cerr << "--dpms argument not understood (" << dpmsArg << ")";
-                }
-            };
-            if (m_dpmsClient->isSupported()) {
-                performSwitch(m_dpmsClient->isSupported());
+            if (dpmsArg == QLatin1String("off")) {
+                m_dpmsClient->switchMode(KScreen::Dpms::Off, screens);
+            } else if (dpmsArg == QLatin1String("on")) {
+                m_dpmsClient->switchMode(KScreen::Dpms::On, screens);
             } else {
-                connect(m_dpmsClient, &Dpms::supportedChanged, this, performSwitch);
+                cerr << "--dpms argument not understood (" << dpmsArg << ")";
             }
         }
         return;
@@ -250,11 +243,7 @@ void Doctor::parseOutputArgs()
                         qApp->exit(5);
                         return;
                     }
-
-                    QPoint p(x, y);
-                    qCDebug(KSCREEN_DOCTOR) << "Output position" << p;
-                    setPosition(output, p);
-
+                    setPosition(output, QPoint(x, y));
                 } else if ((ops.count() == 4 || ops.count() == 5) && subcmd == QLatin1String("scale")) {
                     // be lenient about . vs. comma as separator
                     qreal scale = ops[3].replace(QLatin1Char(','), QLatin1Char('.')).toDouble(&ok);
@@ -264,7 +253,7 @@ void Doctor::parseOutputArgs()
                     };
                     // set scale
                     if (!ok || qFuzzyCompare(scale, 0.0)) {
-                        qCDebug(KSCREEN_DOCTOR) << "Could not set scale " << scale << " to output " << output_id;
+                        qCWarning(KSCREEN_DOCTOR) << "Could not set scale " << scale << " to output " << output_id;
                         qApp->exit(9);
                         return;
                     }
@@ -288,7 +277,7 @@ void Doctor::parseOutputArgs()
                         rot = rotationMap[_rotation];
                     }
                     if (!ok) {
-                        qCDebug(KSCREEN_DOCTOR) << "Could not set orientation " << _rotation << " to output " << output_id;
+                        qCWarning(KSCREEN_DOCTOR) << "Could not set orientation " << _rotation << " to output " << output_id;
                         qApp->exit(9);
                         return;
                     }
@@ -311,7 +300,7 @@ void Doctor::parseOutputArgs()
                     } else if (_policy == QStringLiteral("automatic")) {
                         policy = KScreen::Output::VrrPolicy::Automatic;
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values are \"never\", \"always\" and \"automatic\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values are \"never\", \"always\" and \"automatic\"";
                         qApp->exit(9);
                         return;
                     }
@@ -326,7 +315,7 @@ void Doctor::parseOutputArgs()
                     } else if (_range == QStringLiteral("limited")) {
                         range = KScreen::Output::RgbRange::Limited;
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for rgbrange are \"automatic\", \"full\" and \"limited\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for rgbrange are \"automatic\", \"full\" and \"limited\"";
                         qApp->exit(9);
                         return;
                     }
@@ -338,14 +327,14 @@ void Doctor::parseOutputArgs()
                     } else if (_enable == "disable") {
                         setHdrEnabled(output, false);
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for hdr are \"enable\" and \"disable\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for hdr are \"enable\" and \"disable\"";
                         qApp->exit(9);
                         return;
                     }
                 } else if (ops.count() == 4 && subcmd == "sdr-brightness") {
                     const uint32_t brightness = ops[3].toInt();
                     if (brightness < 100 || brightness > 10000) {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Allowed range for sdr-brightness is 100 to 10000";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Allowed range for sdr-brightness is 100 to 10000";
                         qApp->exit(9);
                         return;
                     }
@@ -357,7 +346,7 @@ void Doctor::parseOutputArgs()
                     } else if (_enable == "disable") {
                         setWcgEnabled(output, false);
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for wcg are \"enable\" and \"disable\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for wcg are \"enable\" and \"disable\"";
                         qApp->exit(9);
                         return;
                     }
@@ -367,11 +356,16 @@ void Doctor::parseOutputArgs()
                         profilePath += "." + ops[i];
                     }
                     output->setIccProfilePath(profilePath);
+                    if (profilePath.isEmpty()) {
+                        output->setColorProfileSource(Output::ColorProfileSource::sRGB);
+                    } else {
+                        output->setColorProfileSource(Output::ColorProfileSource::ICC);
+                    }
                     m_changed = true;
                 } else if (ops.count() >= 4 && subcmd == "sdrGamut") {
                     const uint32_t wideness = ops[3].toUInt();
                     if (wideness > 100) {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Allowed range for sdr wideness is 0 to 100";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Allowed range for sdr wideness is 0 to 100";
                         qApp->exit(9);
                         return;
                     }
@@ -383,7 +377,7 @@ void Doctor::parseOutputArgs()
                     } else if (const uint32_t nits = ops[3].toUInt(); nits != 0) {
                         output->setMaxPeakBrightnessOverride(nits);
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: max brightness must be bigger than 0";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: max brightness must be bigger than 0";
                         qApp->exit(9);
                         return;
                     }
@@ -394,7 +388,7 @@ void Doctor::parseOutputArgs()
                     } else if (const uint32_t nits = ops[3].toUInt(); nits != 0) {
                         output->setMaxAverageBrightnessOverride(nits);
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: max average brightness must be bigger than 0";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: max average brightness must be bigger than 0";
                         qApp->exit(9);
                         return;
                     }
@@ -405,11 +399,33 @@ void Doctor::parseOutputArgs()
                     } else if (const uint32_t nits10k = ops[3].toUInt(); nits10k != 0) {
                         output->setMinBrightnessOverride(nits10k / 10'000.0);
                     } else {
-                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: max average brightness must be bigger than 0";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: max average brightness must be bigger than 0";
                         qApp->exit(9);
                         return;
                     }
                     m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "colorProfileSource") {
+                    if (ops[3] == "sRGB") {
+                        output->setColorProfileSource(Output::ColorProfileSource::sRGB);
+                    } else if (ops[3] == "ICC") {
+                        output->setColorProfileSource(Output::ColorProfileSource::ICC);
+                    } else if (ops[3] == "EDID") {
+                        output->setColorProfileSource(Output::ColorProfileSource::EDID);
+                    } else {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: only allowed values for colorProfileSource are \"sRGB\", \"ICC\" and \"EDID\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "brightness") {
+                    const uint32_t brightness = ops[3].toUInt();
+                    if (brightness > 100) {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Allowed range for brightness is 0 to 100";
+                        qApp->exit(9);
+                        return;
+                    }
+                    output->setBrightness(brightness / 100.0);
+                    m_changed = true;
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -475,8 +491,8 @@ void Doctor::showOutputs() const
         cout << "\t" << (output->isConnected() ? green + QStringLiteral("connected") : red + QStringLiteral("disconnected")) << cr << endl;
         cout << "\t" << (output->isEnabled() ? green : red) + QStringLiteral("priority ") << output->priority() << cr << endl;
         auto _type = typeString[output->type()];
-        cout << "\t" << yellow << (_type.isEmpty() ? QStringLiteral("UnmappedOutputType") : _type) << endl;
-        cout << blue << "\tModes: " << cr;
+        cout << "\t" << yellow << (_type.isEmpty() ? QStringLiteral("UnmappedOutputType") : _type) << cr << endl;
+        cout << "\t" << blue << "Modes: " << cr;
 
         const auto modes = output->modes();
         auto modeKeys = modes.keys();
@@ -551,6 +567,7 @@ void Doctor::showOutputs() const
                 if (const auto used = output->minBrightnessOverride()) {
                     cout << yellow << ", overridden with: " << cr << (*used) / 10'000.0 << " nits";
                 }
+                cout << yellow << "\t\tBrightness factor: " << cr << std::round(output->brightness() * 100) << "%";
                 cout << endl;
             } else {
                 cout << cr << "disabled" << endl;
@@ -578,6 +595,24 @@ void Doctor::showOutputs() const
         } else {
             cout << cr << "incapable" << endl;
         }
+        cout << yellow << "\tColor profile source: ";
+        if (output->capabilities() & Output::Capability::IccProfile) {
+            cout << cr;
+            switch (output->colorProfileSource()) {
+            case Output::ColorProfileSource::sRGB:
+                cout << "sRGB";
+                break;
+            case Output::ColorProfileSource::ICC:
+                cout << "ICC";
+                break;
+            case Output::ColorProfileSource::EDID:
+                cout << "EDID";
+                break;
+            }
+            cout << endl;
+        } else {
+            cout << cr << "incapable" << endl;
+        }
     }
 }
 
